@@ -31,48 +31,52 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+require_once(JPATH_COMPONENT . DS . 'tables' . DS . 'role.php');
+require_once(JPATH_COMPONENT . DS . 'tables' . DS . 'role.type.php');
+
 /**
  * Manage resource author roles
  */
-class ResourcesControllerRoles extends \Hubzero\Component\AdminController
+class ResourcesControllerRoles extends Hubzero_Controller
 {
 	/**
 	 * List resource roles
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function displayTask()
 	{
 		// Get configuration
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$config = JFactory::getConfig();
 
 		// Incoming
 		$this->view->filters = array();
 		$this->view->filters['limit']    = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.limit',
+			$this->_option . '.licenses.limit',
 			'limit',
 			$config->getValue('config.list_limit'),
 			'int'
 		);
 		$this->view->filters['start']    = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.limitstart',
+			$this->_option . '.licenses.limitstart',
 			'limitstart',
 			0,
 			'int'
 		);
 		$this->view->filters['search']     = trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.search',
+			$this->_option . '.licenses.search',
 			'search',
 			''
 		));
 		$this->view->filters['sort']     = trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.sort',
+			$this->_option . '.licenses.sort',
 			'filter_order',
 			'title'
 		));
 		$this->view->filters['sort_Dir'] = trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.sortdir',
+			$this->_option . '.licenses.sortdir',
 			'filter_order_Dir',
 			'ASC'
 		));
@@ -116,7 +120,7 @@ class ResourcesControllerRoles extends \Hubzero\Component\AdminController
 
 	/**
 	 * Add a new role
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function addTask()
@@ -126,7 +130,7 @@ class ResourcesControllerRoles extends \Hubzero\Component\AdminController
 
 	/**
 	 * Edit a role
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function editTask($row=null)
@@ -143,22 +147,19 @@ class ResourcesControllerRoles extends \Hubzero\Component\AdminController
 		{
 			// Incoming (expecting an array)
 			$id = JRequest::getVar('id', array(0));
-			if (is_array($id))
-			{
-				$id = (!empty($id) ? $id[0] : 0);
-			}
+			$id = (is_array($id)) ? $id[0] : 0;
 
 			// Load the object
 			$this->view->row = new ResourcesContributorRole($this->database);
 			$this->view->row->load($id);
 		}
-
+		
 		if (!$this->view->row->id)
 		{
 			$this->view->row->created_by = $this->juser->get('id');
-			$this->view->row->created = JFactory::getDate()->toSql();
+			$this->view->row->created = date('Y-m-d H:i:s', time());
 		}
-
+		
 		$types = $this->view->row->getTypesForRole();
 		if ($types)
 		{
@@ -169,7 +170,7 @@ class ResourcesControllerRoles extends \Hubzero\Component\AdminController
 			}
 			$this->view->row->types = $t;
 		}
-		else
+		else 
 		{
 			$this->view->row->types = array();
 		}
@@ -192,7 +193,7 @@ class ResourcesControllerRoles extends \Hubzero\Component\AdminController
 
 	/**
 	 * Save a role
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function saveTask()
@@ -241,13 +242,13 @@ class ResourcesControllerRoles extends \Hubzero\Component\AdminController
 		// Redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('COM_RESOURCES_ITEM_SAVED')
+			JText::_('Role successfully saved')
 		);
 	}
 
 	/**
 	 * Remove one or more types
-	 *
+	 * 
 	 * @return     void Redirects back to main listing
 	 */
 	public function removeTask()
@@ -257,7 +258,6 @@ class ResourcesControllerRoles extends \Hubzero\Component\AdminController
 
 		// Incoming (expecting an array)
 		$ids = JRequest::getVar('id', array());
-		$ids = (!is_array($ids) ? array($ids) : $ids);
 
 		// Ensure we have an ID to work with
 		if (empty($ids))
@@ -265,7 +265,7 @@ class ResourcesControllerRoles extends \Hubzero\Component\AdminController
 			// Redirect with error message
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-				JText::_('COM_RESOURCES_NO_ITEM_SELECTED'),
+				JText::_('No role selected'),
 				'error'
 			);
 			return;
@@ -282,7 +282,7 @@ class ResourcesControllerRoles extends \Hubzero\Component\AdminController
 		// Redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::sprintf('COM_RESOURCES_ITEMS_REMOVED', count($ids))
+			JText::_('Role(s) successfully removed')
 		);
 	}
 
