@@ -38,11 +38,11 @@ class SupportHtml
 {
 	/**
 	 * Get the status text for a status number
-	 *
+	 * 
 	 * @param      integer $int Status number
-	 * @return     string
+	 * @return     string 
 	 */
-	public static function getStatus($open=0, $status=0)
+	public function getStatus($open=0, $status=0)
 	{
 		/* Old values
 		switch ($int)
